@@ -94,16 +94,22 @@ Applet::Applet(QObject *parent, const QString &serviceID, uint appletId)
 }
 
 Applet::Applet(QObject *parentObject, const QVariantList &args)
-    :  QObject(0),
-       d(new AppletPrivate(KPluginMetaData(), args.count() > 1 ? args[1].toInt() : 0, this))
+    :  QObject(nullptr),
+       d(new AppletPrivate(KPluginMetaData(), args.count() > 2 ? args[2].toInt() : 0, this))
 {
     setParent(parentObject);
-    if (args.count() > 0) {
+    if (!args.isEmpty()) {
         const QVariant first = args.first();
-        if (first.canConvert<QString>()) {
-            d->appletDescription = KPluginMetaData(first.toString());
-        } else if (first.canConvert<QVariantMap>()) {
-            auto metadata = first.toMap().value(QStringLiteral("MetaData")).toMap();
+        if (first.canConvert<KPackage::Package>()) {
+            d->package = first.value<KPackage::Package>();
+        }
+    }
+    if (args.count() > 1) {
+        const QVariant second = args[1];
+        if (second.canConvert<QString>()) {
+            d->appletDescription = KPluginMetaData(second.toString());
+        } else if (second.canConvert<QVariantMap>()) {
+            auto metadata = second.toMap().value(QStringLiteral("MetaData")).toMap();
             d->appletDescription = KPluginMetaData(QJsonObject::fromVariantMap(metadata), {});
         }
     }
@@ -115,12 +121,12 @@ Applet::Applet(QObject *parentObject, const QVariantList &args)
 
     // WARNING: do not access config() OR globalConfig() in this method!
     //          that requires a scene, which is not available at this point
-    d->init(QString(), args.mid(2));
+    d->init(QString(), args.mid(3));
     d->setupPackage();
 }
 
 Applet::Applet(const QString &packagePath, uint appletId)
-    : QObject(0),
+    : QObject(nullptr),
       d(new AppletPrivate(appletMetadataForDirectory(packagePath), appletId, this))
 {
     d->init(packagePath);
@@ -258,7 +264,7 @@ KConfigGroup Applet::globalConfig() const
     QString group = isContainment() ? QStringLiteral("ContainmentGlobals") : QStringLiteral("AppletGlobals");
 
     Containment *cont = containment();
-    Corona *corona = 0;
+    Corona *corona = nullptr;
     if (cont) {
         corona = cont->corona();
     }
@@ -291,10 +297,10 @@ bool Applet::destroyed() const
 KConfigLoader *Applet::configScheme() const
 {
     if (!d->configLoader) {
-        const QString xmlPath = d->package ? d->package->filePath("mainconfigxml") : QString();
+        const QString xmlPath = d->package.isValid() ? d->package.filePath("mainconfigxml") : QString();
         KConfigGroup cfg = config();
         if (xmlPath.isEmpty()) {
-            d->configLoader = new KConfigLoader(cfg, 0);
+            d->configLoader = new KConfigLoader(cfg, nullptr);
         } else {
             QFile file(xmlPath);
             d->configLoader = new KConfigLoader(cfg, &file);
@@ -308,15 +314,13 @@ KConfigLoader *Applet::configScheme() const
 Package Applet::package() const
 {
     Package p;
-    if (d->package) {
-        p.d->internalPackage = new KPackage::Package(*d->package);
-    }
+    p.d->internalPackage = new KPackage::Package(d->package);
     return p;
 }
 
 KPackage::Package Applet::kPackage() const
 {
-    return d->package ? *d->package : KPackage::Package();
+    return d->package;
 }
 
 void Applet::updateConstraints(Plasma::Types::Constraints constraints)
@@ -523,7 +527,7 @@ void Applet::flushPendingConstraintsEvents()
         d->constraintsTimer.stop();
     }
 
-    //qCDebug(LOG_PLASMA) << "fushing constraints: " << d->pendingConstraints << "!!!!!!!!!!!!!!!!!!!!!!!!!!!";
+    //qCDebug(LOG_PLASMA) << "flushing constraints: " << d->pendingConstraints << "!!!!!!!!!!!!!!!!!!!!!!!!!!!";
     Plasma::Types::Constraints c = d->pendingConstraints;
     d->pendingConstraints = Types::NoConstraint;
 
@@ -553,7 +557,7 @@ void Applet::flushPendingConstraintsEvents()
 
         QAction *runAssociatedApplication = d->actions->action(QStringLiteral("run associated application"));
         if (runAssociatedApplication) {
-            connect(runAssociatedApplication, SIGNAL(triggered(bool)), this, SLOT(runAssociatedApplication()), Qt::UniqueConnection);
+            connect(runAssociatedApplication, &QAction::triggered, this, &Applet::runAssociatedApplication, Qt::UniqueConnection);
         }
 
         d->updateShortcuts();
@@ -574,7 +578,7 @@ void Applet::flushPendingConstraintsEvents()
             action->setEnabled(canConfig);
         }
 
-        //an immutable constraint will alwasy happen at startup
+        //an immutable constraint will always happen at startup
         //make sure don't emit a change signal for nothing
         if (d->oldImmutability != immutability()) {
             emit immutabilityChanged(immutability());
@@ -582,7 +586,7 @@ void Applet::flushPendingConstraintsEvents()
         d->oldImmutability = immutability();
     }
 
-    // now take care of constraints in special subclass: Contaiment
+    // now take care of constraints in special subclass: Containment
     Containment *containment = qobject_cast<Plasma::Containment *>(this);
     if (containment) {
         containment->d->containmentConstraintsEvent(c);
@@ -642,7 +646,7 @@ Containment *Applet::containment() const
     if (c && c->isContainment()) {
         return c;
     } else {
-        c = 0;
+        c = nullptr;
     }
 
     QObject *parent = this->parent();
@@ -666,7 +670,7 @@ void Applet::setGlobalShortcut(const QKeySequence &shortcut)
         d->activationAction = new QAction(this);
         d->activationAction->setText(i18n("Activate %1 Widget", title()));
         d->activationAction->setObjectName(QStringLiteral("activate widget %1").arg(id())); // NO I18N
-        connect(d->activationAction, SIGNAL(triggered()), this, SIGNAL(activated()));
+        connect(d->activationAction, &QAction::triggered, this, &Applet::activated);
         connect(d->activationAction, SIGNAL(changed()),
                 this, SLOT(globalShortcutChanged()));
     } else if (d->activationAction->shortcut() == shortcut) {
@@ -783,14 +787,14 @@ Applet *Applet::loadPlasmoid(const QString &path, uint appletId)
     if (md.isValid()) {
         QStringList types = md.serviceTypes();
 
-        if (types.contains(QStringLiteral("Plasma/Containment"))) {
+        if (types.contains(QLatin1String("Plasma/Containment"))) {
             return new Containment(md, appletId);
         } else {
             return new Applet(md, nullptr, appletId);
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 void Applet::timerEvent(QTimerEvent *event)
