@@ -20,7 +20,7 @@
 #ifndef PLASMA_PACKAGE_H
 #define PLASMA_PACKAGE_H
 
-#include <QtCore/QStringList>
+#include <QStringList>
 
 #include <kplugininfo.h>
 
@@ -92,7 +92,7 @@ public:
      * otherwise the structure is allowed to set up the Package's initial layout
      * @since 4.6
      */
-    PLASMA_DEPRECATED explicit Package(PackageStructure *structure = 0);
+    PLASMA_DEPRECATED explicit Package(PackageStructure *structure = nullptr);
 
     /**
      * Copy constructore
